summaryrefslogtreecommitdiffstats
path: root/src/occ_405/amec/amec_controller.c
diff options
context:
space:
mode:
authorWilliam Bryan <wilbryan@us.ibm.com>2016-09-23 12:26:05 -0500
committerWilliam A. Bryan <wilbryan@us.ibm.com>2016-10-11 14:45:04 -0400
commitc21550d3951c6b88f12de2b5aa9565a6c23b6bd4 (patch)
tree6938a483b0d1be783f4ef02d3194fcf4eab015b6 /src/occ_405/amec/amec_controller.c
parent720dfdf376155029a429339f7f862232081ccca0 (diff)
downloadtalos-occ-c21550d3951c6b88f12de2b5aa9565a6c23b6bd4.tar.gz
talos-occ-c21550d3951c6b88f12de2b5aa9565a6c23b6bd4.zip
Save Core & Quad DTS Avgs
Change-Id: I7c57c072f4f84f02ce7bbc5f95c80a4901d6c9a2 RTC:160341 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/30180 Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Reviewed-by: Martha Broyles <mbroyles@us.ibm.com> Reviewed-by: Andres A. Lugo-Reyes <aalugore@us.ibm.com> Reviewed-by: William A. Bryan <wilbryan@us.ibm.com>
Diffstat (limited to 'src/occ_405/amec/amec_controller.c')
-rw-r--r--src/occ_405/amec/amec_controller.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/occ_405/amec/amec_controller.c b/src/occ_405/amec/amec_controller.c
index fee37bb..3f8228a 100644
--- a/src/occ_405/amec/amec_controller.c
+++ b/src/occ_405/amec/amec_controller.c
@@ -88,9 +88,9 @@ void amec_controller_proc_thermal()
/*------------------------------------------------------------------------*/
/* Code */
/*------------------------------------------------------------------------*/
// Get TEMP4MSP0PEAK sensor, which is hottest core temperature in OCC
// processor
- l_sensor = getSensorByGsid(TEMP4MSP0PEAK);
+ l_sensor = getSensorByGsid(TEMPPROCTHRM);
// Use the highest temperature of all processors in 0.1 degrees C
l_thermal_winner = l_sensor->sample * 10;
OpenPOWER on IntegriCloud
@@ -88,9 +88,9 @@ void amec_controller_proc_thermal()
/* Code */
/*------------------------------------------------------------------------*/
- // Get TEMP4MSP0PEAK sensor, which is hottest core temperature in OCC
+ // Get TEMPPROCTHRM sensor, which is hottest core temperature in OCC
// processor